# -*- coding: utf-8 -*-
"""
Sistema de Consulta Pública

Copyleft (@) 2017 CENDITEL nodo Mérida - https://planificacion.cenditel.gob.ve/trac/wiki/ModeladoTopicos_2017
"""
## @package users.models
#
# Modelos correspondientes a los usuarios
# @author Rodrigo Boet (rboet at cenditel.gob.ve)
# @author <a href='http://www.cenditel.gob.ve'>Centro Nacional de Desarrollo e Investigación en Tecnologías Libres
# (CENDITEL) nodo Mérida - Venezuela</a>
# @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
# @version 1.0
from __future__ import unicode_literals

from django.db import models
from django.contrib.auth.models import User
from base.models import Parroquia
from base.constant import SECTORES, PARTICIPACION, SECTOR_TRABAJADOR, SECTOR_ESTUDIANTE, TIPO_INSTITUCION

class Universidades(models.Model):
    """!
    Clase que gestiona los datos de las universidades

    @author Rodrigo Boet (rboet at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 08-09-2017
    @version 1.0.0
    """
    ## Nombre de la institución
    nombre = models.CharField(max_length=80,unique=True)
    
    ## Tipo de institución
    tipo = models.CharField(max_length=3,choices=TIPO_INSTITUCION)

class Perfil(models.Model):
    """!
    Clase que gestiona los datos de los perfiles

    @author Rodrigo Boet (rboet at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 20-04-2017
    @version 1.0.0
    """    
    ## Número de Cédula
    cedula = models.CharField(max_length=10,unique=True)
    
    ## Relación con la parroquía
    parroquia = models.ForeignKey(Parroquia)
    
    ## Sector al que pertenece
    sector = models.CharField(max_length=2,choices=SECTORES)
    
    ## Sector Trabajador al que pertenece
    sector_trabajador = models.CharField(max_length=2,choices=SECTOR_TRABAJADOR,default='')
    
    ## Sector Estudiante al que pertenece
    sector_estudiante = models.CharField(max_length=3,choices=SECTOR_ESTUDIANTE,default='')
    
    ## Tipo de participacion (Individual o Colectiva)
    participacion = models.CharField(max_length=2,choices=PARTICIPACION)
    
    ## Nombre del colectivo al que pertenece (si aplica)
    colectivo = models.CharField(max_length=50,default='')
    
    ## Relación con el modelo de universidades
    universidad = models.ForeignKey(Universidades,null=True)
    
    ## Relación con el user de django
    user = models.ForeignKey(User)
    